#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_INTERP1_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_INTERP1_HPP_INCLUDED

#include <nt2/interpol/include/functions/scalar/interp1.hpp>

#endif
